==> localnews-base-service-1.3.0.2-sources.jar: com/bxm/localnews/base/service/impl/AreaInfoServiceImpl.java <==
package com.bxm.localnews.base.service.impl;

import com.bxm.localnews.base.domain.AreaInfoMapper;
import com.bxm.localnews.base.service.AreaInfoService;
import com.bxm.localnews.common.constant.RedisConfig;
import com.bxm.localnews.common.vo.AreaInfo;
import com.bxm.newidea.component.redis.KeyGenerator;
import com.bxm.newidea.component.redis.RedisStringAdapter;
import com.bxm.newidea.component.service.BaseService;
import com.fasterxml.jackson.core.type.TypeReference;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Optional;

@Service
public class AreaInfoServiceImpl extends BaseService implements AreaInfoService {

    private final AreaInfoMapper areaInfoMapper;

    private final RedisStringAdapter redisStringAdapter;

    @Autowired
    public AreaInfoServiceImpl(AreaInfoMapper areaInfoMapper, RedisStringAdapter redisStringAdapter) {
        this.areaInfoMapper = areaInfoMapper;
        this.redisStringAdapter = redisStringAdapter;
    }

    @Override
    public AreaInfo getAreaInfo(String code) {

        KeyGenerator areaInfoKey = RedisConfig.AREA_INFO;
        TypeReference<List<AreaInfo>> areaInfoTypeReference = new TypeReference<List<AreaInfo>>() {
        };
        AreaInfo areaInfo = null;
        List<AreaInfo> areaInfoList = redisStringAdapter.get(areaInfoKey, areaInfoTypeReference);
        if (areaInfoList != null) {
            Optional<AreaInfo> areaInfoOptional = areaInfoList.stream().filter(x -> x.getCode().equals(code)).findFirst();
            if (areaInfoOptional.isPresent()) {
                areaInfo = areaInfoOptional.get();
            }
        }

        if (null == areaInfo) {
            areaInfoList = areaInfoMapper.selectByModel(null);
            redisStringAdapter.set(areaInfoKey, areaInfoList);
            areaInfo = areaInfoMapper.selectByCode(code);
        }

        return areaInfo;
    }

}

==> localnews-base-service-2.0.0-sources.jar: com/bxm/localnews/base/service/impl/AreaInfoServiceImpl.java <==
package com.bxm.localnews.base.service.impl;

import com.bxm.localnews.base.domain.AreaInfoMapper;
import com.bxm.localnews.base.dto.LocationDTO;
import com.bxm.localnews.base.service.AreaInfoService;
import com.bxm.localnews.base.service.LocationService;
import com.bxm.localnews.common.constant.RedisConfig;
import com.bxm.localnews.common.vo.AreaInfo;
import com.bxm.newidea.component.redis.KeyGenerator;
import com.bxm.newidea.component.redis.RedisStringAdapter;
import com.bxm.newidea.component.service.BaseService;
import com.fasterxml.jackson.core.type.TypeReference;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Optional;

@Service
public class AreaInfoServiceImpl extends BaseService implements AreaInfoService {

    private final AreaInfoMapper areaInfoMapper;

    private final RedisStringAdapter redisStringAdapter;

    private final LocationService locationService;

    @Autowired
    public AreaInfoServiceImpl(AreaInfoMapper areaInfoMapper, RedisStringAdapter redisStringAdapter,LocationService locationService) {
        this.areaInfoMapper = areaInfoMapper;
        this.redisStringAdapter = redisStringAdapter;
        this.locationService =locationService;
    }

    @Override
    public AreaInfo getAreaInfo(String code) {
        LocationDTO locationDTO = locationService.getInternalLocationByGeocode(code);

        KeyGenerator areaInfoKey = RedisConfig.AREA_INFO;
        TypeReference<List<AreaInfo>> areaInfoTypeReference = new TypeReference<List<AreaInfo>>() {
        };
        AreaInfo areaInfo = null;
        List<AreaInfo> areaInfoList = redisStringAdapter.get(areaInfoKey, areaInfoTypeReference);
        if (areaInfoList != null) {
            Optional<AreaInfo> areaInfoOptional = areaInfoList.stream().filter(x -> x.getCode().equals(code)).findFirst();
            if (areaInfoOptional.isPresent()) {
                areaInfo = areaInfoOptional.get();
            }
        }

        if (null == areaInfo) {
            areaInfoList = areaInfoMapper.selectByModel(null);
            redisStringAdapter.set(areaInfoKey, areaInfoList);
            areaInfo = areaInfoMapper.selectByCode(code);
        }

        if (null == areaInfo) {
            areaInfo = new AreaInfo();
        }

        areaInfo.setCode(locationDTO.getCode());
        areaInfo.setName(locationDTO.getName());

        return areaInfo;
    }

}
